@@ -4,12 +4,12 @@ Postprocess.R2GUESS <- function(x){
   command <- paste(x$command," -postProcess ",sep="")
   print(command)
   if (.Platform$OS.type == "unix") {
-	system(command)
+    system(command)
   } else if (.Platform$OS.type == "windows") {
-	shell(command)
+    shell(command)
   }
   
-  Namefeatures <- paste(x$path.output,x$root.file.output,"_features.txt",sep="")
+  Namefeatures <- file.path(x$path.output, paste(x$root.file.output,"features.txt",sep="_"))
   features <- read.table(file=Namefeatures,header=TRUE)
   rownames(features) <- features[,1]
   
